package VMOMI::HostLowLevelProvisioningManagerReloadTarget;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
